[![](https://ucspython.herokuapp.com/badge.svg)](https://ucspython.herokuapp.com)

# Python SDK for Cisco UCS Central

* Apache License, Version 2.0 (the "License")

## Installation

### From github:

Installs the latest top of the tree development version,

```
    # Install pip (skip if pip is already available):
    wget https://bootstrap.pypa.io/get-pip.py
    python get-pip.py

    git clone https://github.com/CiscoUcs/ucscsdk.git
    cd ucscsdk
    make install
```

### From pip

```
    pip install ucscsdk
```

## Community:

* We are on Slack - slack requires registration, but the ucspython team is open invitation to
  anyone to register [here](https://ucspython.herokuapp.com)
